/**
 * Permissions configuration of a data collection.
 *
 * Describes who can perform certain data operations on a collection.
 */
interface DataPermissions {
    /**
     * Data Collection ID that is subject of these permissions
     * @immutable
     * @maxLength 255
     */
    _id?: string;
    /** Access level for data items read */
    itemRead?: AccessLevelWithLiterals;
    /** Access level for data items insert */
    itemInsert?: AccessLevelWithLiterals;
    /** Access level for data items update */
    itemUpdate?: AccessLevelWithLiterals;
    /** Access level for data items removal */
    itemRemove?: AccessLevelWithLiterals;
}
/**
 * Describes who can perform certain action.
 * Each level includes all levels below it (except UNDEFINED).
 */
declare enum AccessLevel {
    /** Not set */
    UNKNOWN = "UNKNOWN",
    /** Any subject, including visitors */
    ANYONE = "ANYONE",
    /** Any signed-in user (both site members and collaborators) */
    SITE_MEMBER = "SITE_MEMBER",
    /** Any signed-in user, but site members only have access to own items */
    SITE_MEMBER_AUTHOR = "SITE_MEMBER_AUTHOR",
    /** Site collaborator that has a role with CMS Access permission */
    CMS_EDITOR = "CMS_EDITOR",
    /** CMS administrators and users or roles granted with special access */
    PRIVILEGED = "PRIVILEGED"
}
/** @enumType */
type AccessLevelWithLiterals = AccessLevel | 'UNKNOWN' | 'ANYONE' | 'SITE_MEMBER' | 'SITE_MEMBER_AUTHOR' | 'CMS_EDITOR' | 'PRIVILEGED';
/** Special access granted to user or role */
interface SpecialPermissions extends SpecialPermissionsSubjectOneOf {
    /**
     * User ID that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    userId?: string;
    /**
     * Policy ID of (custom) role that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    policyId?: string;
    /**
     * ID of this special access, so it can be managed separately
     * @format GUID
     * @readonly
     */
    _id?: string;
    /** If data item read is allowed */
    itemRead?: AccessWithLiterals;
    /** If data item insert is allowed */
    itemInsert?: AccessWithLiterals;
    /** If data item update is allowed */
    itemUpdate?: AccessWithLiterals;
    /** If data item remove is allowed */
    itemRemove?: AccessWithLiterals;
}
/** @oneof */
interface SpecialPermissionsSubjectOneOf {
    /**
     * User ID that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    userId?: string;
    /**
     * Policy ID of (custom) role that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    policyId?: string;
}
declare enum Access {
    /** Action is not specifically allowed, but can be allowed by top-level permissions */
    UNSPECIFIED = "UNSPECIFIED",
    /** Action is specifically allowed */
    ALLOWED = "ALLOWED"
}
/** @enumType */
type AccessWithLiterals = Access | 'UNSPECIFIED' | 'ALLOWED';
interface GetPermissionsRequest {
    /**
     * Data Collection ID to get permissions for
     * @maxLength 256
     */
    dataCollectionId: string;
}
interface GetPermissionsResponse {
    /** Requested data permissions */
    dataPermissions?: DataPermissions;
}
interface UpdatePermissionsRequest {
    /** Data permissions to update */
    dataPermissions: DataPermissions;
}
interface UpdatePermissionsResponse {
    /** Updated data permissions */
    dataPermissions?: DataPermissions;
}
interface AddSpecialPermissionsRequest {
    /**
     * Data Collection ID to add special permission for
     * @maxLength 256
     */
    dataCollectionId: string;
    /** Special permissions to add */
    specialPermissions: SpecialPermissions;
}
interface AddSpecialPermissionsResponse {
    /** Added special data permissions */
    specialPermissions?: SpecialPermissions;
}
interface UpdateSpecialPermissionsRequest {
    /** Special permissions to update */
    specialPermissions: SpecialPermissions;
}
interface UpdateSpecialPermissionsResponse {
    /** Updated special data permissions */
    specialPermissions?: SpecialPermissions;
}
interface RemoveSpecialPermissionsRequest {
    /**
     * Special permissions ID to remove
     * @format GUID
     */
    specialPermissionsId: string;
}
interface RemoveSpecialPermissionsResponse {
}
interface GetMyPermissionsRequest {
    /**
     * Data Collection ID to get permission for
     * @maxLength 256
     */
    dataCollectionId: string;
}
interface GetMyPermissionsResponse {
    /** If data item read is allowed */
    itemRead?: boolean;
    /** If data item insert is allowed */
    itemInsert?: boolean;
    /** If data item update is allowed */
    itemUpdate?: boolean;
    /** If data item remove is allowed */
    itemRemove?: boolean;
}
interface MigrateCustomRolesRequest {
    /**
     * Role ID to update, if empty updates all roles in scope
     * @format GUID
     */
    policyId?: string | null;
}
interface MigrateCustomRolesResponse {
}
interface PolicyAssignmentsUpdated extends PolicyAssignmentsUpdatedEventOneOf {
    policyAssigned?: PolicyAssigned;
    policyUnassigned?: PolicyUnassigned;
    policyAssignmentUpdated?: PolicyAssignmentUpdated;
}
/** @oneof */
interface PolicyAssignmentsUpdatedEventOneOf {
    policyAssigned?: PolicyAssigned;
    policyUnassigned?: PolicyUnassigned;
    policyAssignmentUpdated?: PolicyAssignmentUpdated;
}
interface PolicyAssigned {
    subject?: Subject;
    assignment?: PolicyAssignment[];
}
interface Subject {
    /** ID of identity assigned to the asset. */
    _id?: string;
    /** Type of identity assigned to the asset. Supported subject types include user IDs, account IDs, and app IDs. */
    subjectType?: SubjectTypeWithLiterals;
    /** Context of identity assigned to the asset. For example, a `subjectType` = `USER` will have `context` = `ACCOUNT`. */
    context?: SubjectContext;
}
declare enum SubjectType {
    UNKNOWN = "UNKNOWN",
    ACCOUNT = "ACCOUNT",
    USER = "USER",
    USER_GROUP = "USER_GROUP",
    MEMBER_GROUP = "MEMBER_GROUP",
    VISITOR_GROUP = "VISITOR_GROUP",
    EXTERNAL_APP = "EXTERNAL_APP",
    ACCOUNT_GROUP = "ACCOUNT_GROUP",
    WIX_APP = "WIX_APP"
}
/** @enumType */
type SubjectTypeWithLiterals = SubjectType | 'UNKNOWN' | 'ACCOUNT' | 'USER' | 'USER_GROUP' | 'MEMBER_GROUP' | 'VISITOR_GROUP' | 'EXTERNAL_APP' | 'ACCOUNT_GROUP' | 'WIX_APP';
interface SubjectContext {
    _id?: string;
    contextType?: SubjectContextTypeWithLiterals;
}
declare enum SubjectContextType {
    UNKNOWN_CTX = "UNKNOWN_CTX",
    ORG_CTX = "ORG_CTX",
    ACCOUNT_CTX = "ACCOUNT_CTX"
}
/** @enumType */
type SubjectContextTypeWithLiterals = SubjectContextType | 'UNKNOWN_CTX' | 'ORG_CTX' | 'ACCOUNT_CTX';
interface PolicyAssignment {
    policyId?: string;
    resource?: ResourcePath;
    condition?: PolicyCondition;
    assignmentId?: string | null;
}
interface ResourcePath {
    organization?: string | null;
    account?: string | null;
    site?: string | null;
    resource?: Resource;
}
/**
 * A custom resource. Is used to represent some asset that is not a direct resource context (site or account), but something custom.
 * For example: payment method, blog post, domain, logo.
 */
interface Resource {
    /** The resource id. */
    _id?: string | null;
    /** The resource type */
    type?: string | null;
}
interface PolicyCondition {
    /** The type of the condition */
    condition?: ConditionType;
}
interface ConditionType extends ConditionTypeOfOneOf {
    /** @deprecated */
    simpleCondition?: SimpleCondition;
    /** A logic combination between several conditions, with an operator between them */
    joinedConditions?: JoinedCondition;
    /** @deprecated */
    environmentCondition?: EnvironmentCondition;
    /** A single condition */
    condition?: Condition;
}
/** @oneof */
interface ConditionTypeOfOneOf {
    /** @deprecated */
    simpleCondition?: SimpleCondition;
    /** A logic combination between several conditions, with an operator between them */
    joinedConditions?: JoinedCondition;
    /** @deprecated */
    environmentCondition?: EnvironmentCondition;
    /** A single condition */
    condition?: Condition;
}
interface SimpleCondition {
    attrName?: string;
    value?: SimpleConditionValue;
    op?: SimpleConditionOperatorWithLiterals;
    conditionModelId?: string;
}
interface SimpleConditionValue extends SimpleConditionValueValueOneOf {
    attrName?: string;
    stringValue?: string;
    boolValue?: boolean;
}
/** @oneof */
interface SimpleConditionValueValueOneOf {
    attrName?: string;
    stringValue?: string;
    boolValue?: boolean;
}
declare enum SimpleConditionOperator {
    UNKNOWN_SIMPLE_OP = "UNKNOWN_SIMPLE_OP",
    EQUAL = "EQUAL"
}
/** @enumType */
type SimpleConditionOperatorWithLiterals = SimpleConditionOperator | 'UNKNOWN_SIMPLE_OP' | 'EQUAL';
interface JoinedCondition {
    /** The operator that should be used when evaluating the condition */
    op?: JoinedConditionOperatorWithLiterals;
    /** The conditions that should be evaluated, and then joined using the operator provided */
    conditions?: ConditionType[];
}
declare enum JoinedConditionOperator {
    UNKNOWN_JOIN_OP = "UNKNOWN_JOIN_OP",
    OR = "OR",
    AND = "AND"
}
/** @enumType */
type JoinedConditionOperatorWithLiterals = JoinedConditionOperator | 'UNKNOWN_JOIN_OP' | 'OR' | 'AND';
interface EnvironmentCondition extends EnvironmentConditionConditionOneOf {
    experimentCondition?: ExperimentCondition;
}
/** @oneof */
interface EnvironmentConditionConditionOneOf {
    experimentCondition?: ExperimentCondition;
}
interface ExperimentCondition {
    spec?: string;
    fallbackValue?: string;
    expectedValue?: string;
}
interface Condition {
    /** The unique identifier of the condition model. Indicates which actions the condition is working on */
    conditionModelId?: string;
    /** The operator that should be evaluated */
    operator?: ConditionOperator;
}
interface ConditionOperator extends ConditionOperatorOperatorsOneOf {
    /** Comparison of equality - will be evaluated to true if the given parties are equal */
    equals?: EqualOperator;
    /** Regex operator - will be evaluated to true if the given value matches the provided regex */
    like?: LikeOperator;
    /** Petri experiment - will be evaluated using petri. */
    experiment?: ExperimentOperator;
    /** Operator that indicates a dependency on another subject being allowed to perform something. */
    dependOn?: DependOnOperator;
}
/** @oneof */
interface ConditionOperatorOperatorsOneOf {
    /** Comparison of equality - will be evaluated to true if the given parties are equal */
    equals?: EqualOperator;
    /** Regex operator - will be evaluated to true if the given value matches the provided regex */
    like?: LikeOperator;
    /** Petri experiment - will be evaluated using petri. */
    experiment?: ExperimentOperator;
    /** Operator that indicates a dependency on another subject being allowed to perform something. */
    dependOn?: DependOnOperator;
}
interface EqualOperator {
    /** The attribute which should be compared. The attribute will be first evaluated to a value, and then compared the other side (attribute/value) */
    attrName?: string;
    /** The value to compare to. If the two parties are equal - we will return true. */
    value?: ConditionValue;
}
interface ConditionValue extends ConditionValueValueOneOf {
    /** an attribute. We'll first retrieve the value of the attribute (from the request or from pre-indexed values), and then compare to what it needs to be compared with. */
    attrName?: string;
    /** a value with a string type. Will be compared to the attribute provided, and be true only if they match the operator. */
    stringValue?: string;
    /** a value with a boolean type. Will be compared to the attribute provided, and be true only if they match the operator. */
    boolValue?: boolean;
}
/** @oneof */
interface ConditionValueValueOneOf {
    /** an attribute. We'll first retrieve the value of the attribute (from the request or from pre-indexed values), and then compare to what it needs to be compared with. */
    attrName?: string;
    /** a value with a string type. Will be compared to the attribute provided, and be true only if they match the operator. */
    stringValue?: string;
    /** a value with a boolean type. Will be compared to the attribute provided, and be true only if they match the operator. */
    boolValue?: boolean;
}
interface LikeOperator {
    /** The attribute which should be compared. The attribute will be first evaluated to a value, and then compared the regex values provided. */
    attrName?: string;
    /** The regex values which the attribute value should be evaluated on. If the attribute value matches at least one of the regular expressions provided - we will return true */
    values?: string[];
}
interface ExperimentOperator {
    /** The spec to conduct the experiment on. */
    spec?: string;
    /** The value to use if the experiment could not be conducted */
    fallbackValue?: string;
    /** The expected value of the experiment conduction. If it matches the actual value - true will be returned. Otherwise - false. */
    expectedValue?: string;
}
/** Implies that the policy takes affect only if the depend on subject is permitted as well. */
interface DependOnOperator {
    /** The subject on which the current entry depends on. If the subject is allowed to perform what the query was about - the condition will be evaluated to true. Otherwise - false */
    dependOnSubject?: Subject;
}
interface PolicyUnassigned {
    subject?: Subject;
    assignment?: PolicyAssignment[];
}
interface PolicyAssignmentUpdated {
    subject?: Subject;
    fromAssignment?: PolicyAssignment[];
    toAssignment?: PolicyAssignment[];
}
interface Empty {
}
interface PolicyAuthorizationDataUpdated {
    policyId?: string;
    fromPolicyStatements?: PolicyStatement[];
    toPolicyStatements?: PolicyStatement[];
    policyType?: PolicyTypeWithLiterals;
    policyOwner?: PolicyOwner;
}
interface PolicyStatement {
    /** @readonly */
    _id?: string | null;
    permissions?: string[];
    scopes?: string[];
    effect?: EffectWithLiterals;
    condition?: PolicyCondition;
}
declare enum Effect {
    UNKNOWN_EFFECT = "UNKNOWN_EFFECT",
    ALLOW = "ALLOW",
    DENY = "DENY"
}
/** @enumType */
type EffectWithLiterals = Effect | 'UNKNOWN_EFFECT' | 'ALLOW' | 'DENY';
declare enum PolicyType {
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    PREDEFINED = "PREDEFINED",
    CUSTOM = "CUSTOM",
    INLINE_CUSTOM = "INLINE_CUSTOM"
}
/** @enumType */
type PolicyTypeWithLiterals = PolicyType | 'UNKNOWN_STATUS' | 'PREDEFINED' | 'CUSTOM' | 'INLINE_CUSTOM';
interface PolicyOwner {
    type?: PolicyOwnerTypeWithLiterals;
    _id?: string;
}
declare enum PolicyOwnerType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    WIX = "WIX",
    WIX_ACCOUNT = "WIX_ACCOUNT"
}
/** @enumType */
type PolicyOwnerTypeWithLiterals = PolicyOwnerType | 'UNKNOWN_TYPE' | 'WIX' | 'WIX_ACCOUNT';
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface AddSpecialPermissionsOptions {
    /** Special permissions to add */
    specialPermissions: SpecialPermissions;
}
interface UpdateSpecialPermissions {
    /**
     * User ID that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    userId?: string;
    /**
     * Policy ID of (custom) role that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    policyId?: string;
    /**
     * ID of this special access, so it can be managed separately
     * @format GUID
     * @readonly
     */
    _id?: string;
    /** If data item read is allowed */
    itemRead?: AccessWithLiterals;
    /** If data item insert is allowed */
    itemInsert?: AccessWithLiterals;
    /** If data item update is allowed */
    itemUpdate?: AccessWithLiterals;
    /** If data item remove is allowed */
    itemRemove?: AccessWithLiterals;
}

export { type ExperimentOperator as $, type AddSpecialPermissionsOptions as A, type PolicyCondition as B, type ConditionType as C, type DataPermissions as D, Effect as E, type ConditionTypeOfOneOf as F, type GetPermissionsResponse as G, type SimpleCondition as H, type SimpleConditionValue as I, JoinedConditionOperator as J, type SimpleConditionValueValueOneOf as K, type JoinedCondition as L, type MigrateCustomRolesRequest as M, type EnvironmentCondition as N, type EnvironmentConditionConditionOneOf as O, PolicyType as P, type ExperimentCondition as Q, type RemoveSpecialPermissionsRequest as R, SubjectType as S, type Condition as T, type UpdatePermissionsResponse as U, type ConditionOperator as V, type ConditionOperatorOperatorsOneOf as W, type EqualOperator as X, type ConditionValue as Y, type ConditionValueValueOneOf as Z, type LikeOperator as _, type AddSpecialPermissionsResponse as a, type DependOnOperator as a0, type PolicyUnassigned as a1, type PolicyAssignmentUpdated as a2, type Empty as a3, type PolicyAuthorizationDataUpdated as a4, type PolicyStatement as a5, type PolicyOwner as a6, type DomainEvent as a7, type DomainEventBodyOneOf as a8, type EntityCreatedEvent as a9, type RestoreInfo as aa, type EntityUpdatedEvent as ab, type EntityDeletedEvent as ac, type ActionEvent as ad, type UpdateSpecialPermissions as b, type UpdateSpecialPermissionsResponse as c, type GetMyPermissionsResponse as d, AccessLevel as e, Access as f, SubjectContextType as g, SimpleConditionOperator as h, PolicyOwnerType as i, type SpecialPermissions as j, type SpecialPermissionsSubjectOneOf as k, type GetPermissionsRequest as l, type UpdatePermissionsRequest as m, type AddSpecialPermissionsRequest as n, type UpdateSpecialPermissionsRequest as o, type RemoveSpecialPermissionsResponse as p, type GetMyPermissionsRequest as q, type MigrateCustomRolesResponse as r, type PolicyAssignmentsUpdated as s, type PolicyAssignmentsUpdatedEventOneOf as t, type PolicyAssigned as u, type Subject as v, type SubjectContext as w, type PolicyAssignment as x, type ResourcePath as y, type Resource as z };
